Sovereign Grace Churches | Our Churches
Author: Church Plant Media
Description: See a map of our local churches and a brief overview of what to expect at them.
Keywords: sovereign grace, sovereign grace churches, local churches

# Our Churches

- Map View
- List View

Search by City, State, or Country Reset and Show All

- North America
- Latin America
- Europe
- Africa
- Asia/Pacific

Sort by: State
Reset and Show All

#### Christ Church

christchurchphilly.org|Philadelphia, PA

Lead Pastor: Jeff Boettcher|Email: [javascript protected email address]

Church Details

#### Christ Community Church

christcchurch.org|Covington, LA

Lead Pastor: Jeff Ehrhardt|Email: [javascript protected email address]

Church Details

#### Christ Community Church

cccberks.org|Shillington, PA

Lead Pastor: C.B. Eder|Email: [javascript protected email address]

Church Details

#### Community of Grace

cogamherst.org|Williamsville, NY

Lead Pastor: Rob Saathoff|Email: [javascript protected email address]

Church Details

#### Cornerstone Church of Knoxville

cornerstonechurchofknoxville.com|Knoxville, TN

Lead Pastor: Bill Kittrell|Email: [javascript protected email address]

Church Details

#### Covenant Community Church

cccwestphilly.com|Philadelphia, PA

Lead Pastor: Andrew Kalvelage|Email: [javascript protected email address]

Church Details

#### Covenant Fellowship Church

covfel.org|Glen Mills, PA

Lead Pastor: Jared Mellinger|Email: [javascript protected email address]

Church Details

#### Covenant Life Fellowship

clfroseburg.com|Roseburg, OR

Lead Pastor: David York|Email: [javascript protected email address]

Church Details

#### Covenant of Grace Church

cogc.org|Copley, OH

Lead Pastor: Jace Hudson|Email: [javascript protected email address]

Church Details

#### Cross of Grace Church

crossgrace.org|Chaska, MN

Lead Pastor: Scott Crook|Email: [javascript protected email address]

Church Details

#### Cross of Grace Church

crossofgrace.net|El Paso, TX

Lead Pastor: Ricky Alcantar|Email: [javascript protected email address]

Church Details

#### CrossHaven Church

crosshavenbelleville.org|Belleville, IL

Lead Pastor: Chris Oswald|Email: [javascript protected email address]

Church Details

#### CrossPointe Church

crosspointemd.org|Arnold, MD

Lead Pastor: Ed O'Mara|Email: [javascript protected email address]

Church Details

#### Crossway Church

crosswayma.org|Franklin, MA

Lead Pastor: Bauer Evans|Email: [javascript protected email address]

Church Details

#### Crossway Church

crosswaypa.org|Millersville, PA

Lead Pastor: Peter Privitera|Email: [javascript protected email address]

Church Details

#### CrossWay Community Church

crosswayfl.org|Crestview, FL

Lead Pastor: Jim Brown|Email: [javascript protected email address]

Church Details

#### CrossWay Community Church

crosswaync.org|Charlotte, NC

Lead Pastor: Mickey Connolly|Email: [javascript protected email address]

Church Details

#### Emmaus Road Church

emmausroadsf.com|Sioux Falls, SD

Lead Pastor: Greg Dirnberger|Email: [javascript protected email address]

Church Details

#### Grace Church

gracechurchaz.org|Peoria, AZ

Lead Pastor: Chris Daukas|Email: [javascript protected email address]

Church Details

#### Grace Church

gracechurchfrisco.org|Frisco, TX

Lead Pastor: Craig Cabaniss|Email: [javascript protected email address]

Church Details

#### Grace Church

gracechurchorlando.org|Gotha, FL

Lead Pastor: Wayne Brooks|Email: [javascript protected email address]

Church Details

#### Grace Church of Clarksburg

gracechurchmd.org|Germantown, MD

Lead Pastor: Larry Malament|Email: [javascript protected email address]

Church Details

#### Grace City Church of the Northeast

gracecityne.com|Philadelphia, PA

Lead Pastor: Ian McConnell|Email: [javascript protected email address]

Church Details

#### Grace City Church of Wissinoming

wiss.gracecityphilly.com|Philadelphia, PA

Lead Pastor: Dan Birkholz|Email: [javascript protected email address]

Church Details

#### Grace Community Church

www.gccdenver.org|Westminster, CO

Lead Pastor: Glynn McKenzie|Email: [javascript protected email address]

Church Details

#### Grace Community Church

gcchurch.org|Souderton, PA

Lead Pastor: Jeremy Bell|Email: [javascript protected email address]

Church Details

#### Grace Community Church

gracemelbourne.org|Melbourne, FL

Lead Pastor: Cary Hughes|Email: [javascript protected email address]

Church Details

#### Grace Community Church

gracecommunity.ws|Ashburn, VA

Lead Pastor: Bob Donohue|Email: [javascript protected email address]

Church Details

#### Grace Covenant Church

gccjax.org|Jacksonville, FL

Lead Pastor: Joe Calabello|Email: [javascript protected email address]

Church Details

#### Grace Life Fellowship

gracelifene.org|Hastings, NE

Lead Pastor: Chad Haygood|Email: [javascript protected email address]

Church Details

#### Iglesia Gracia Soberana de Gaithersburg

graciasob.org|Gaithersburg, MD

Lead Pastor: José Mercado|Email: [javascript protected email address]

Church Details

#### King of Grace Church

kingofgrace.org|Haverhill, MA

Lead Pastor: Paul Buckley|Email: [javascript protected email address]

Church Details

#### Kingdom Life Church

kingdom-life.org|Nassau

Lead Pastor: Cedric Moss|Email: [javascript protected email address]

Church Details

#### KingsWay Community Church

kingsway.cc|Midlothian, VA

Lead Pastor: Matthew Williams|Email: [javascript protected email address]

Church Details

#### Lakeview Christian Center

lakeviewchristiancenter.com|New Orleans, LA

Lead Pastor: Keith Collins|Email: [javascript protected email address]

Church Details

#### Lifegate Church

lifegateseguin.com|Seguin, TX

Lead Pastor: Bob Odom|Email: [javascript protected email address]

Church Details

#### Living Faith Church

lfcwv.org|Franklin, WV

Lead Pastor: Steve Teter|Email: [javascript protected email address]

Church Details

#### Living Hope Church

lhc-pa.org|Harrisburg, PA

Lead Pastor: Ken Mellinger|Email: [javascript protected email address]

Church Details

#### Living Hope Church

livinghopebowie.org|Bowie, MD

Lead Pastor: John Loftness|Email: [javascript protected email address]

Church Details

#### Misión de Gracia

misiondegracia.com|El Paso, TX

Lead Pastor: Hellman Avila|Email: [javascript protected email address]

Church Details

#### Providence Community Church

sovgracekc.org|Lenexa, KS

Lead Pastor: Matthew Wassink|Email: [javascript protected email address]

Church Details

#### Redeemer Church

lakenonachurch.com|Orlando, FL

Lead Pastor: Benny Phillips|Email: [javascript protected email address]

Church Details

#### Redeeming Grace Church

redeeminggracenc.org|Durham, NC

Lead Pastor: Eric Holter|Email: [javascript protected email address]

Church Details

#### Redeeming Grace Church

rgcnashville.com|Franklin, TN

Lead Pastor: Dave Odom|Email: [javascript protected email address]

Church Details

#### Redemption Hill Church

rhchurch.com|Round Rock, TX

Lead Pastor: Jon Payne|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sovgracetucson.org|Tucson, AZ

Lead Pastor: Derek Overstreet|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sgcco.org|Aurora, CO

Lead Pastor: Mark Alderton|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sgcatlanta.org|Woodstock, GA

Lead Pastor: Aaron Anderson|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sgclagrange.com|LaGrange, GA

Lead Pastor: Russell Tusing|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sovgracemd.net|Baltimore, MD

Lead Pastor: Jimmy Cannon|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sovgracemn.org|Bloomington, MN

Lead Pastor: Rick Gamache|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sovgracenc.org|Apex, NC

Lead Pastor: Phil Sasser|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sovgracenj.org|Marlton, NJ

Lead Pastor: Warren Boettcher|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sgcdayton.org|Bellbrook, OH

Lead Pastor: Steve Bice|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sgcmidland.org|Midland, TX

Lead Pastor: Billy Raies|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sovereigngracepearland.org|Pearland, TX

Lead Pastor: Grady VanWright|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sgcfredericksburg.org|Spotsylvania, VA

Lead Pastor: Ken Delage|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sovgracechurch.com|Gilbert, AZ

Lead Pastor: Rich Richardson|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church of Louisville

sgclouisville.org|Louisville, KY

Lead Pastor: C.J. Mahaney|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church of Orange

sovgraceoc.org|Orange, CA

Lead Pastor: Eric Turbedsky|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church of Pasadena

sovgracepasadena.org|Pasadena, CA

Lead Pastor: Ron Boomsma|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church of the Lowcountry

sgclowcountry.org|Ladson, SC

Lead Pastor: Mike Seaver|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church Toronto

sovgraceto.org|King City, ON

Lead Pastor: Tim Kerr|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Community Church

sovereigngrace.cc|Roanoke, VA

Lead Pastor: Bruce Chick|Email: [javascript protected email address]

Church Details

#### The Chapel

tcindy.org|Indianapolis, IN

Lead Pastor: Randy Worland|Email: [javascript protected email address]

Church Details

#### Trinity Fellowship Church

trinityfel.org|Toms River, NJ

Lead Pastor: Steve Cassarino|Email: [javascript protected email address]

Church Details

#### Iglesia Cristiana Gracia Soberana de Aguascalientes

Aguascalientes,

Lead Pastor: Elías Reyes|Email: [javascript protected email address]

Church Details

#### Iglesia en La Paz

iglesiaenlapaz.org|La Paz

Lead Pastor: Johnny Dueri|Email: [javascript protected email address]

Church Details

#### Iglesia Gracia Soberana de Cd. Juárez

graciasoberana.org|Juárez, Chih.

Lead Pastor: Carlos Contreras|Email: [javascript protected email address]

Church Details

#### Arche Church

arche-gemeinde.de|Hamburg

Lead Pastor: Christian Wegert|Email: [javascript protected email address]

Church Details

#### Grace Church Bristol

gracechurchbristol.org|Fishponds, Bristol

Lead Pastor: Nathan Smith|Email: [javascript protected email address]

Church Details

#### Christ Community Church

Ndola

Lead Pastor: Wilbroad Chanda|Email: [javascript protected email address]

Church Details

#### City of Refuge Church

https://www.facebook.com/YouGoChurch|Addis Ababa

Lead Pastor: Molalign Adugna|Email: [javascript protected email address]

Church Details

#### His Dwelling Church

hisdwellingchristianchurch.wordpress.com|Cebu City 6000

Lead Pastor: Cornelio Ebo|Email: [javascript protected email address]

Church Details

#### Lord’s Grace Church

sgmlordsgrace.org/home|Gwacheon Si, Gyeonggi-Do, Seoul

Lead Pastor: Songhwan Kang|Email: [javascript protected email address]

Church Details

#### Sovereign Grace Church

sovgrace.org.au|Wahroonga NSW 2076, Sydney

Lead Pastor: Dave Taylor|Email: [javascript protected email address]

Church Details